========
Property
========

The Property commands are used to create and manage reinforcements and to assign properties to a part.
(See also Material commands and Section commands.) The Property commands are methods of a Part object.

Create properties for Part
--------------------------

.. autoclass:: abaqus.Property.PropertyPart.PropertyPart
    :noindex:

    .. autoclasstoc::

.. This is a comment ro supress the warning "(ERROR/3) Document may not end with a transition."
